@@ -141,7 +141,7 @@ GRL_PLUGIN_DEFINE (GRL_MAJOR,
                    "A plugin to get metadata using chromaprint framework",
                    "Victor Toso",
                    VERSION,
-                   "LGPL",
+                   "LGPL-2.1-or-later",
                    "http://victortoso.com",
                    grl_chromaprint_plugin_init,
                    NULL,
