@@ -36,8 +36,6 @@
 #define MEDIA_ID_PREFIX "dleyna:"
 #define MEDIA_ID_PREFIX_LENGTH 7
 
-#define DLEYNA_DBUS_NAME "com.intel.dleyna-server"
-
 #define DLEYNA_SEARCH_SPEC                \
   "(DisplayName contains \"%s\" or "      \
   "Album contains \"%s\" or "             \
@@ -73,6 +71,14 @@ enum {
   PROP_SERVER
 };
 
+typedef enum {
+  CONTAINER_TYPE_ALBUM,
+  CONTAINER_TYPE_ARTIST,
+  CONTAINER_TYPE_GENRE,
+  CONTAINER_TYPE_UNKNOWN,
+  CONTAINER_TYPE_NOT_CONTAINER
+} ContainerType;
+
 typedef enum {
   DLEYNA_CHANGE_TYPE_ADD = 1,
   DLEYNA_CHANGE_TYPE_MOD = 2,
@@ -297,21 +303,22 @@ grl_dleyna_source_update_caps_cb (GObject    *gobject,
   }
   else {
     gchar **cap;
-    gboolean type, displayname, album, artist, parent;
-    type = displayname = album = artist = parent = FALSE;
+    gboolean type, type_ex, displayname, album, artist, parent;
+    type = type_ex = displayname = album = artist = parent = FALSE;
 
     GRL_DEBUG ("%s caps:", G_STRFUNC);
     for (cap = (gchar **) search_caps; *cap != NULL; cap++) {
       GRL_DEBUG ("  %s", *cap);
       type = type || (g_strcmp0(*cap, "Type") == 0);
+      type_ex = type_ex || (g_strcmp0 (*cap, "TypeEx") == 0);
       displayname = displayname || (g_strcmp0(*cap, "DisplayName") == 0);
       album = album || (g_strcmp0(*cap, "Album") == 0);
       artist = artist || (g_strcmp0(*cap, "Artist") == 0);
       parent = parent || (g_strcmp0(*cap, "Parent") == 0);
     }
 
-    source->priv->search_enabled = type && (displayname || album || artist);
-    source->priv->browse_filtered_enabled = type && parent;
+    source->priv->search_enabled = type && type_ex && (displayname || album || artist);
+    source->priv->browse_filtered_enabled = type && type_ex && parent;
   }
 
   GRL_DEBUG ("%s %s search:%d filtered:%d", G_STRFUNC, grl_source_get_id (GRL_SOURCE (source)),
@@ -463,10 +470,32 @@ properties_add_for_key (GPtrArray *properties,
     }
 }
 
+static ContainerType
+get_container_type (const gchar *type_ex)
+{
+  ContainerType con_type = CONTAINER_TYPE_UNKNOWN;
+
+  if (g_strcmp0 (type_ex, "container.person.musicArtist") == 0) {
+    con_type = CONTAINER_TYPE_ARTIST;
+  }
+  if (g_strcmp0 (type_ex, "container.album.musicAlbum") == 0) {
+    con_type = CONTAINER_TYPE_ALBUM;
+  }
+  if (g_strcmp0 (type_ex, "container.genre.musicGenre") == 0) {
+    con_type = CONTAINER_TYPE_GENRE;
+  }
+  if (g_str_has_prefix (type_ex, "item")) {
+    con_type = CONTAINER_TYPE_NOT_CONTAINER;
+  }
+
+  return con_type;
+}
+
 static void
 media_set_property (GrlMedia *media,
                     const gchar *key,
-                    GVariant *value)
+                    GVariant *value,
+                    ContainerType container_type)
 {
   const gchar *s;
   gint i;
@@ -478,6 +507,23 @@ media_set_property (GrlMedia *media,
   else if (g_strcmp0 (key, "DisplayName") == 0) {
     s = g_variant_get_string (value, NULL);
     grl_media_set_title (media, s);
+    switch (container_type) {
+      case CONTAINER_TYPE_ALBUM:
+        grl_media_set_album (media, s);
+        break;
+      case CONTAINER_TYPE_ARTIST:
+        grl_media_set_artist (media, s);
+        break;
+      case CONTAINER_TYPE_GENRE:
+        grl_media_set_genre (media, s);
+        break;
+      case CONTAINER_TYPE_NOT_CONTAINER:
+        grl_media_set_title (media, s);
+        break;
+      default:
+        grl_media_set_title (media, s);
+        break;
+    }
   }
   else if (g_strcmp0 (key, "URLs") == 0 && g_variant_n_children (value) > 0) {
     g_variant_get_child (value, 0, "&s", &s);
@@ -497,19 +543,19 @@ media_set_property (GrlMedia *media,
   }
   else if (g_strcmp0 (key, "Artist") == 0) {
     s = g_variant_get_string (value, NULL);
-    if (grl_media_is_audio (media)) {
+    if (grl_media_is_audio (media) || grl_media_is_container (media)) {
       grl_media_set_artist (media, s);
     }
   }
   else if (g_strcmp0 (key, "Album") == 0) {
     s = g_variant_get_string (value, NULL);
-    if (grl_media_is_audio (media)) {
+    if (grl_media_is_audio (media) || grl_media_is_container (media)) {
       grl_media_set_album (media, s);
     }
   }
   else if (g_strcmp0 (key, "Genre") == 0) {
     s = g_variant_get_string (value, NULL);
-    if (grl_media_is_audio (media)) {
+    if (grl_media_is_audio (media) || grl_media_is_container (media)) {
       grl_media_set_genre (media, s);
     }
   }
@@ -572,7 +618,8 @@ media_set_property (GrlMedia *media,
 
 static GrlMedia *
 populate_media_from_variant (GrlMedia *media,
-                             GVariant *variant)
+                             GVariant *variant,
+                             ContainerType container_type)
 {
   GVariantIter iter;
   const gchar *key;
@@ -580,7 +627,7 @@ populate_media_from_variant (GrlMedia *media,
 
   g_variant_iter_init (&iter, variant);
   while (g_variant_iter_next (&iter, "{&sv}", &key, &value)) {
-    media_set_property (media, key, value);
+    media_set_property (media, key, value, container_type);
     g_variant_unref (value);
   }
 
@@ -592,8 +639,12 @@ build_media_from_variant (GVariant *variant)
 {
   GrlMedia *media;
   const gchar *type = NULL;
+  const gchar *type_ex = NULL;
 
   g_variant_lookup (variant, "Type", "&s", &type);
+  g_variant_lookup (variant, "TypeEx", "&s", &type_ex);
+
+  ContainerType container_type = get_container_type (type_ex);
 
   if (type == NULL) {
     media = grl_media_new ();
@@ -621,7 +672,7 @@ build_media_from_variant (GVariant *variant)
     media = grl_media_new ();
   }
 
-  populate_media_from_variant (media, variant);
+  populate_media_from_variant (media, variant, container_type);
 
   return media;
 }
@@ -743,6 +794,7 @@ build_properties_filter (const GList *keys)
   filter = g_ptr_array_new ();
   g_ptr_array_add (filter, "Path"); /* always retrieve the items' DBus path */
   g_ptr_array_add (filter, "Type"); /* and their object type */
+  g_ptr_array_add (filter, "TypeEx"); /* and their object extended type */
   while (keys != NULL) {
     properties_add_for_key (filter, GRLPOINTER_TO_KEYID (keys->data));
     keys = g_list_next (keys);
@@ -849,6 +901,7 @@ grl_dleyna_source_resolve_browse_objects_cb (GObject      *object,
                                              GAsyncResult *res,
                                              gpointer      user_data)
 {
+  ContainerType container_type = CONTAINER_TYPE_UNKNOWN;
   GrlDleynaMediaDevice *device = GRL_DLEYNA_MEDIA_DEVICE (object);
   GrlSourceResolveSpec *rs = user_data;
   GVariant *results, *dict, *item_error;
@@ -883,7 +936,7 @@ grl_dleyna_source_resolve_browse_objects_cb (GObject      *object,
     return;
   }
 
-  populate_media_from_variant (rs->media, dict);
+  populate_media_from_variant (rs->media, dict, container_type);
   rs->callback (rs->source, rs->operation_id, rs->media, rs->user_data, NULL);
 }
 
