@@ -24,9 +24,6 @@
 #ifndef _GRL_COMMON_H_
 #define _GRL_COMMON_H_
 
-#include <grilo.h>
-#include <libdmapsharing/dmap.h>
-
 typedef struct {
   GrlSourceResultCb callback;
   GrlSource *source;
@@ -41,9 +38,9 @@ typedef struct {
 
 typedef struct {
   ResultCbAndArgs cb;
-  DMAPDb *db;
+  DmapDb *db;
 } ResultCbAndArgsAndDb;
 
-gchar *grl_dmap_build_url (DMAPMdnsBrowserService *service);
+gchar *grl_dmap_build_url (DmapMdnsService *service);
 
 #endif /* _GRL_COMMON_H_ */
