@@ -54,8 +54,12 @@
 #include <sys/stat.h>
 #include <sys/types.h>
 #include <glib.h>
+#include <grilo.h>
 #include <string.h>
+#include <libdmapsharing/dmap.h>
 
+#include "grl-daap-compat.h"
+#include "grl-common.h"
 #include "grl-daap-db.h"
 
 #define ALBUMS_ID    "albums"
@@ -66,7 +70,7 @@
 /* Media ID's start at max and go down. Container ID's start at 1 and go up. */
 static guint nextid = G_MAXINT; /* NOTE: this should be G_MAXUINT, but iPhoto can't handle it. */
 
-struct GrlDAAPDbPrivate {
+struct GrlDaapDbPrivate {
   /* Contains each album container (tracked with albums hash table) */
   GrlMedia *albums_container;
 
@@ -95,31 +99,31 @@ container_equal (gconstpointer a, gconstpointer b)
   return g_str_equal (grl_media_get_id (GRL_MEDIA (a)), grl_media_get_id (GRL_MEDIA (b)));
 }
 
-GrlDAAPDb *
+GrlDaapDb *
 grl_daap_db_new (void)
 {
-  GrlDAAPDb *db = g_object_new (TYPE_GRL_DAAP_DB, NULL);
+  GrlDaapDb *db = g_object_new (TYPE_GRL_DAAP_DB, NULL);
 
   return db;
 }
 
-static DMAPRecord *
-grl_daap_db_lookup_by_id (const DMAPDb *db, guint id)
+static DmapRecord *
+grl_daap_db_lookup_by_id (const DmapDb *db, guint id)
 {
   g_error ("Not implemented");
   return NULL;
 }
 
 static void
-grl_daap_db_foreach (const DMAPDb *db,
-                        GHFunc func,
-                        gpointer data)
+grl_daap_db_foreach (const DmapDb *db,
+                     DmapIdRecordFunc func,
+                     gpointer data)
 {
   g_error ("Not implemented");
 }
 
 static gint64
-grl_daap_db_count (const DMAPDb *db)
+grl_daap_db_count (const DmapDb *db)
 {
   g_error ("Not implemented");
   return 0;
@@ -135,7 +139,7 @@ set_insert (GHashTable *category, const char *category_name, char *set_name, Grl
   id = g_strdup_printf ("%s-%s", category_name, set_name);
 
   container = grl_media_container_new ();
-  grl_media_set_id    (container, id);
+  grl_media_set_id (container, id);
   grl_media_set_title (container, set_name);
 
   set = g_hash_table_lookup (category, container);
@@ -150,14 +154,14 @@ set_insert (GHashTable *category, const char *category_name, char *set_name, Grl
   g_object_unref (container);
 }
 
-static guint
-grl_daap_db_add (DMAPDb *_db, DMAPRecord *_record)
+guint
+grl_daap_db_add (DmapDb *_db, DmapRecord *_record, GError **error)
 {
-  g_assert (IS_GRL_DAAP_DB (_db));
-  g_assert (IS_DAAP_RECORD (_record));
+  g_assert (GRL_IS_DAAP_DB (_db));
+  g_assert (DMAP_IS_AV_RECORD (_record));
 
-  GrlDAAPDb *db = GRL_DAAP_DB (_db);
-  DAAPRecord *record = DAAP_RECORD (_record);
+  GrlDaapDb *db = GRL_DAAP_DB (_db);
+  DmapAvRecord *record = DMAP_AV_RECORD (_record);
 
   gint   duration = 0;
   gint32  bitrate = 0,
@@ -173,26 +177,16 @@ grl_daap_db_add (DMAPDb *_db, DMAPRecord *_record)
   GrlMedia *media;
 
   g_object_get (record,
-               "songalbum",
-               &album,
-               "songartist",
-               &artist,
-               "bitrate",
-               &bitrate,
-               "duration",
-               &duration,
-               "songgenre",
-               &genre,
-               "title",
-               &title,
-               "track",
-               &track,
-               "disc",
-               &disc,
-               "location",
-               &url,
-               "has-video",
-               &has_video,
+               "songalbum", &album,
+               "songartist", &artist,
+               "bitrate", &bitrate,
+               "duration", &duration,
+               "songgenre", &genre,
+               "title", &title,
+               "track", &track,
+               "disc", &disc,
+               "location", &url,
+               "has-video", &has_video,
                 NULL);
 
   id_s = g_strdup_printf ("%u", nextid);
@@ -203,8 +197,8 @@ grl_daap_db_add (DMAPDb *_db, DMAPRecord *_record)
     media = grl_media_audio_new ();
   }
 
-  grl_media_set_id           (media, id_s);
-  grl_media_set_duration     (media, duration);
+  grl_media_set_id (media, id_s);
+  grl_media_set_duration (media, duration);
 
   if (title) {
     grl_media_set_title (media, title);
@@ -217,7 +211,7 @@ grl_daap_db_add (DMAPDb *_db, DMAPRecord *_record)
   }
 
   if (has_video == FALSE) {
-    grl_media_set_bitrate      (media, bitrate);
+    grl_media_set_bitrate (media, bitrate);
     grl_media_set_track_number (media, track);
 
     if (disc != 0) {
@@ -242,6 +236,11 @@ grl_daap_db_add (DMAPDb *_db, DMAPRecord *_record)
 
   g_free (id_s);
   g_object_unref (media);
+  g_free (album);
+  g_free (artist);
+  g_free (genre);
+  g_free (title);
+  g_free (url);
 
   return --nextid;
 }
@@ -249,11 +248,11 @@ grl_daap_db_add (DMAPDb *_db, DMAPRecord *_record)
 static gboolean
 same_media (GrlMedia *a, GrlMedia *b)
 {
-  return (strcmp (grl_media_get_id (a), grl_media_get_id (b)) == 0);
+  return strcmp (grl_media_get_id (a), grl_media_get_id (b)) == 0;
 }
 
 void
-grl_daap_db_browse (GrlDAAPDb *db,
+grl_daap_db_browse (GrlDaapDb *db,
                     GrlMedia *container,
                     GrlSource *source,
                     guint op_id,
@@ -262,7 +261,7 @@ grl_daap_db_browse (GrlDAAPDb *db,
                     GrlSourceResultCb func,
                     gpointer user_data)
 {
-  g_assert (IS_GRL_DAAP_DB (db));
+  g_assert (GRL_IS_DAAP_DB (db));
 
   int i;
   guint remaining;
@@ -312,7 +311,7 @@ done:
 }
 
 void
-grl_daap_db_search (GrlDAAPDb *db,
+grl_daap_db_search (GrlDaapDb *db,
                     GrlSource *source,
                     guint op_id,
                     GHRFunc predicate,
@@ -320,7 +319,7 @@ grl_daap_db_search (GrlDAAPDb *db,
                     GrlSourceResultCb func,
                     gpointer user_data)
 {
-  g_assert (IS_GRL_DAAP_DB (db));
+  g_assert (GRL_IS_DAAP_DB (db));
 
   gint i, j, k;
   guint remaining = 0;
@@ -334,7 +333,7 @@ grl_daap_db_search (GrlDAAPDb *db,
   results = g_hash_table_new (g_str_hash, g_str_equal);
 
   /* For albums and artists... */
-  for (i = 0; i < G_N_ELEMENTS(hash_tables); i++) {
+  for (i = 0; i < G_N_ELEMENTS (hash_tables); i++) {
     g_hash_table_iter_init (&iter1, hash_tables[i]);
     /* For each album or artist in above... */
     for (j = 0; g_hash_table_iter_next (&iter1, &key1, &val1); j++) {
@@ -364,18 +363,18 @@ grl_daap_db_search (GrlDAAPDb *db,
 static void
 dmap_db_interface_init (gpointer iface, gpointer data)
 {
-  DMAPDbIface *daap_db = iface;
+  DmapDbInterface *daap_db = iface;
 
   g_assert (G_TYPE_FROM_INTERFACE (daap_db) == DMAP_TYPE_DB);
 
-  daap_db->add = grl_daap_db_add;
+  daap_db->add = grl_daap_db_add_compat;
   daap_db->lookup_by_id = grl_daap_db_lookup_by_id;
   daap_db->foreach = grl_daap_db_foreach;
   daap_db->count = grl_daap_db_count;
 }
 
-G_DEFINE_TYPE_WITH_CODE (GrlDAAPDb, grl_daap_db, G_TYPE_OBJECT,
-                         G_ADD_PRIVATE (GrlDAAPDb)
+G_DEFINE_TYPE_WITH_CODE (GrlDaapDb, grl_daap_db, G_TYPE_OBJECT,
+                         G_ADD_PRIVATE (GrlDaapDb)
                          G_IMPLEMENT_INTERFACE (DMAP_TYPE_DB, dmap_db_interface_init))
 
 static GObject*
@@ -389,17 +388,17 @@ grl_daap_db_constructor (GType type, guint n_construct_params, GObjectConstructP
 }
 
 static void
-grl_daap_db_init (GrlDAAPDb *db)
+grl_daap_db_init (GrlDaapDb *db)
 {
   db->priv = grl_daap_db_get_instance_private (db);
 
   db->priv->albums_container  = grl_media_container_new ();
   db->priv->artists_container = grl_media_container_new ();
 
-  grl_media_set_id    (GRL_MEDIA (db->priv->albums_container), ALBUMS_ID);
+  grl_media_set_id (GRL_MEDIA (db->priv->albums_container), ALBUMS_ID);
   grl_media_set_title (GRL_MEDIA (db->priv->albums_container), ALBUMS_NAME);
 
-  grl_media_set_id    (GRL_MEDIA (db->priv->artists_container), ARTISTS_ID);
+  grl_media_set_id (GRL_MEDIA (db->priv->artists_container), ARTISTS_ID);
   grl_media_set_title (GRL_MEDIA (db->priv->artists_container), ARTISTS_NAME);
 
   db->priv->root    = g_hash_table_new_full (container_hash, container_equal, g_object_unref, (GDestroyNotify) g_hash_table_destroy);
@@ -413,9 +412,9 @@ grl_daap_db_init (GrlDAAPDb *db)
 static void
 grl_daap_db_finalize (GObject *object)
 {
-  GrlDAAPDb *db = GRL_DAAP_DB (object);
+  GrlDaapDb *db = GRL_DAAP_DB (object);
 
-  GRL_DEBUG ("Finalizing GrlDAAPDb");
+  GRL_DEBUG ("Finalizing GrlDaapDb");
 
   g_object_unref (db->priv->albums_container);
   g_object_unref (db->priv->artists_container);
@@ -426,9 +425,9 @@ grl_daap_db_finalize (GObject *object)
 
 static void
 grl_daap_db_set_property (GObject *object,
-                             guint prop_id,
-                             const GValue *value,
-                             GParamSpec *pspec)
+                          guint prop_id,
+                          const GValue *value,
+                          GParamSpec *pspec)
 {
   switch (prop_id) {
   default:
@@ -439,9 +438,9 @@ grl_daap_db_set_property (GObject *object,
 
 static void
 grl_daap_db_get_property (GObject *object,
-                             guint prop_id,
-                             GValue *value,
-                             GParamSpec *pspec)
+                          guint prop_id,
+                          GValue *value,
+                          GParamSpec *pspec)
 {
   switch (prop_id) {
   default:
@@ -452,7 +451,7 @@ grl_daap_db_get_property (GObject *object,
 
 
 static void
-grl_daap_db_class_init (GrlDAAPDbClass *klass)
+grl_daap_db_class_init (GrlDaapDbClass *klass)
 {
   GObjectClass *object_class = G_OBJECT_CLASS (klass);
 
