@@ -20,9 +20,14 @@
  *
  */
 
+#include <grilo.h>
+#include <libdmapsharing/dmap.h>
+
+#include "grl-daap-compat.h"
+#include "grl-common.h"
 #include "grl-daap-record.h"
 
-struct GrlDAAPRecordPrivate {
+struct GrlDaapRecordPrivate {
   guint64 filesize;
   char *location;
   char *format;
@@ -69,11 +74,11 @@ enum {
 
 static void
 grl_daap_record_set_property (GObject *object,
-                                 guint prop_id,
-                                 const GValue *value,
-                                 GParamSpec *pspec)
+                              guint prop_id,
+                              const GValue *value,
+                              GParamSpec *pspec)
 {
-  GrlDAAPRecord *record = SIMPLE_DAAP_RECORD (object);
+  GrlDaapRecord *record = SIMPLE_DAAP_RECORD (object);
 
   switch (prop_id) {
   case PROP_LOCATION:
@@ -86,27 +91,27 @@ grl_daap_record_set_property (GObject *object,
     break;
   case PROP_ALBUM:
     g_free (record->priv->album);
-    record->priv->album = g_value_dup_string(value);
+    record->priv->album = g_value_dup_string (value);
     break;
   case PROP_SORT_ALBUM:
     g_free (record->priv->sort_album);
-    record->priv->sort_album = g_value_dup_string(value);
+    record->priv->sort_album = g_value_dup_string (value);
     break;
   case PROP_ARTIST:
     g_free (record->priv->artist);
-    record->priv->artist = g_value_dup_string(value);
+    record->priv->artist = g_value_dup_string (value);
     break;
   case PROP_SORT_ARTIST:
     g_free (record->priv->sort_artist);
-    record->priv->sort_artist = g_value_dup_string(value);
+    record->priv->sort_artist = g_value_dup_string (value);
     break;
   case PROP_GENRE:
     g_free (record->priv->genre);
-    record->priv->genre = g_value_dup_string(value);
+    record->priv->genre = g_value_dup_string (value);
     break;
   case PROP_FORMAT:
     g_free (record->priv->format);
-    record->priv->format = g_value_dup_string(value);
+    record->priv->format = g_value_dup_string (value);
     break;
   case PROP_MEDIAKIND:
     record->priv->mediakind = g_value_get_enum (value);
@@ -142,20 +147,18 @@ grl_daap_record_set_property (GObject *object,
     record->priv->has_video = g_value_get_boolean (value);
     break;
   default:
-    G_OBJECT_WARN_INVALID_PROPERTY_ID (object,
-                                       prop_id,
-                                       pspec);
+    G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
     break;
   }
 }
 
 static void
 grl_daap_record_get_property (GObject *object,
-                                 guint prop_id,
-                                 GValue *value,
-                                 GParamSpec *pspec)
+                              guint prop_id,
+                              GValue *value,
+                              GParamSpec *pspec)
 {
-  GrlDAAPRecord *record = SIMPLE_DAAP_RECORD (object);
+  GrlDaapRecord *record = SIMPLE_DAAP_RECORD (object);
 
   switch (prop_id) {
   case PROP_LOCATION:
@@ -216,21 +219,19 @@ grl_daap_record_get_property (GObject *object,
     g_value_set_boolean (value, record->priv->has_video);
     break;
   default:
-    G_OBJECT_WARN_INVALID_PROPERTY_ID (object,
-                                       prop_id,
-                                       pspec);
+    G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
     break;
   }
 }
 
-GrlDAAPRecord *
+GrlDaapRecord *
 grl_daap_record_new (void)
 {
   return SIMPLE_DAAP_RECORD (g_object_new (TYPE_SIMPLE_DAAP_RECORD, NULL));
 }
 
 GInputStream *
-grl_daap_record_read (DAAPRecord *record, GError **error)
+grl_daap_record_read (DmapAvRecord *record, GError **error)
 {
   GFile *file;
   GInputStream *stream;
@@ -244,7 +245,7 @@ grl_daap_record_read (DAAPRecord *record, GError **error)
 }
 
 static void
-grl_daap_record_init (GrlDAAPRecord *record)
+grl_daap_record_init (GrlDaapRecord *record)
 {
   record->priv = SIMPLE_DAAP_RECORD_GET_PRIVATE (record);
 }
@@ -252,7 +253,7 @@ grl_daap_record_init (GrlDAAPRecord *record)
 static void grl_daap_record_finalize (GObject *object);
 
 static void
-grl_daap_record_class_init (GrlDAAPRecordClass *klass)
+grl_daap_record_class_init (GrlDaapRecordClass *klass)
 {
   GObjectClass *gobject_class = G_OBJECT_CLASS (klass);
 
@@ -284,9 +285,9 @@ grl_daap_record_class_init (GrlDAAPRecordClass *klass)
 static void
 grl_daap_record_daap_iface_init (gpointer iface, gpointer data)
 {
-  DAAPRecordIface *daap_record = iface;
+  DmapAvRecordInterface *daap_record = iface;
 
-  g_assert (G_TYPE_FROM_INTERFACE (daap_record) == DAAP_TYPE_RECORD);
+  g_assert (G_TYPE_FROM_INTERFACE (daap_record) == DMAP_TYPE_AV_RECORD);
 
   daap_record->read = grl_daap_record_read;
 }
@@ -294,21 +295,21 @@ grl_daap_record_daap_iface_init (gpointer iface, gpointer data)
 static void
 grl_daap_record_dmap_iface_init (gpointer iface, gpointer data)
 {
-  DMAPRecordIface *dmap_record = iface;
+  DmapRecordInterface *dmap_record = iface;
 
   g_assert (G_TYPE_FROM_INTERFACE (dmap_record) == DMAP_TYPE_RECORD);
 }
 
 
-G_DEFINE_TYPE_WITH_CODE (GrlDAAPRecord, grl_daap_record, G_TYPE_OBJECT,
-                         G_ADD_PRIVATE (GrlDAAPRecord)
-                         G_IMPLEMENT_INTERFACE (DAAP_TYPE_RECORD, grl_daap_record_daap_iface_init)
+G_DEFINE_TYPE_WITH_CODE (GrlDaapRecord, grl_daap_record, G_TYPE_OBJECT,
+                         G_ADD_PRIVATE (GrlDaapRecord)
+                         G_IMPLEMENT_INTERFACE (DMAP_TYPE_AV_RECORD, grl_daap_record_daap_iface_init)
                          G_IMPLEMENT_INTERFACE (DMAP_TYPE_RECORD, grl_daap_record_dmap_iface_init))
 
 static void
 grl_daap_record_finalize (GObject *object)
 {
-  GrlDAAPRecord *record = SIMPLE_DAAP_RECORD (object);
+  GrlDaapRecord *record = SIMPLE_DAAP_RECORD (object);
 
   g_free (record->priv->location);
   g_free (record->priv->title);
