@@ -199,7 +199,7 @@ GRL_PLUGIN_DEFINE (GRL_MAJOR,
                    "A plugin for browsing the filesystem",
                    "Igalia S.L.",
                    VERSION,
-                   "LGPL",
+                   "LGPL-2.1-or-later",
                    "http://www.igalia.com",
                    grl_filesystem_plugin_init,
                    NULL,
