@@ -158,7 +158,7 @@ GRL_PLUGIN_DEFINE (GRL_MAJOR,
                    "A plugin that gets a list of subtitles for a video",
                    "Bastien Nocera",
                    VERSION,
-                   "LGPL",
+                   "LGPL-2.1-or-later",
                    "http://www.hadess.net",
                    grl_opensubtitles_source_plugin_init,
                    NULL,
