@@ -290,7 +290,7 @@ GRL_PLUGIN_DEFINE (GRL_MAJOR,
                    "A plugin for fetching metadata of television shows",
                    "Victor Toso",
                    VERSION,
-                   "LGPL",
+                   "LGPL-2.1-or-later",
                    "http://victortoso.com",
                    grl_thetvdb_plugin_init,
                    NULL,
